==> nocc-1.8.1.tbz: www/nocc/lang/zh-hant.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hant.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Traditional Chinese (‪中文(繁體)‬)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cary Leung <cary@cary.net>
 */

$lang_locale = 'zh_TW.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '登入名字之位置空白';
$err_passwd_empty = '密碼之位置空白';
$alt_delete = '删除已選擇之信件';
$alt_delete_one = '删除此信件';
$alt_new_msg = '新信件';
$alt_reply = '回覆信件';
$alt_reply_all = '回覆所有人';
$alt_forward = '轉寄';
$title_next_msg = '下一封';
$title_prev_msg = '上一封';
$html_on = '在';
$html_theme_label = '背景主題';
$html_welcome = '歡迎到 %1$s';
$html_login = '登入';
$html_passwd = '密碼';
$html_submit = '提交';
$html_help = '幫助';
$html_server = '伺服器';
$html_wrong = '登入名字或密碼不正確';
$html_retry = '再嘗試';
$html_view_header = '顯示標題';
$html_remove_header = '不顯示標題';
$html_inbox = '信箱';
$html_new_msg = '寫信件';
$html_reply = '回覆';
$html_reply_short = '回覆';
$html_reply_all = '回覆所有人';
$html_forward = '轉寄';
$html_forward_short = '轉寄';
$html_delete = '删除';
$html_new = '新';
$html_mark = '删除';
$html_att_label = '附件';
$html_atts_label = '附件';
$html_att_unknown = '[不明]';
$html_attach = '附件';
$html_attach_forget = '你忘記加入附件 !';
$html_attach_delete = '删除已選擇的';
$html_from = '由';
$html_subject = '題目';
$html_date = '日期';
$html_sent = '傳送';
$html_size = '體積';
$html_totalsize = '總體積';
$html_filename = '檔名';
$html_to = '收件人';
$html_cc = '複製至';
$html_nosubject = '無題目';
$html_send = '傳送';
$html_cancel = '取消';
$html_no_mail = '無內容.';
$html_logout = '登出';
$html_msg = '信件';
$html_msgs = '信件';
$original_msg = '-- 原始內容 --';
$to_empty = '此 \'收件人\' 之位置不能沒有 !';
$html_err_file_contacts = 'Unable to open contacts file for writing.';

==> nocc-1.8.3.tbz: www/nocc/lang/zh-hant.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hant.php 2171 2010-04-08 23:52:07Z siebrand $
 */

/** Traditional Chinese (‪中文(繁體)‬)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cary Leung <cary@cary.net>
 */

$lang_locale = 'zh_TW.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '登入名字之位置空白';
$err_passwd_empty = '密碼之位置空白';
$alt_delete = '删除已選擇之信件';
$alt_delete_one = '删除此信件';
$alt_new_msg = '新信件';
$alt_reply = '回覆信件';
$alt_reply_all = '回覆所有人';
$alt_forward = '轉寄';
$title_next_msg = '下一封';
$title_prev_msg = '上一封';
$html_theme_label = '背景主題';
$html_welcome = '歡迎到 %1$s';
$html_login = '登入';
$html_submit = '提交';
$html_help = '幫助';
$html_wrong = '登入名字或密碼不正確';
$html_retry = '再嘗試';
$html_view_header = '顯示標題';
$html_remove_header = '不顯示標題';
$html_inbox = '信箱';
$html_new_msg = '寫信件';
$html_reply = '回覆';
$html_reply_short = '回覆';
$html_reply_all = '回覆所有人';
$html_forward = '轉寄';
$html_forward_short = '轉寄';
$html_delete = '删除';
$html_new = '新';
$html_mark = '删除';
$html_att_label = '附件';
$html_unknown = '[不明]';
$html_attach = '附件';
$html_attach_forget = '你忘記加入附件 !';
$html_attach_delete = '删除已選擇的';
$html_from = '由';
$html_subject = '題目';
$html_date = '日期';
$html_sent_label = '傳送';
$html_size = '體積';
$html_totalsize = '總體積';
$html_filename = '檔名';
$html_to = '收件人';
$html_cc = '複製至';
$html_nosubject = '無題目';
$html_send = '傳送';
$html_cancel = '取消';
$html_no_mail = '無內容.';
$html_logout = '登出';
$html_msg = '信件';
$html_msgs = '信件';
$original_msg = '-- 原始內容 --';
$to_empty = '此 \'收件人\' 之位置不能沒有 !';
$html_err_file_contacts = 'Unable to open contacts file for writing.';
